<?php

use EventPortal\Domain\Agenda\Handlers\AssociateToPathway;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Agenda\Rules\NoOverlap;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Input\TextArea;
use EventPortal\Domain\Component\Input\TimeInput;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Domain\Handlers\UpdateModel;

$fields = function (Pathway $pathway) {
    return [
        Section::make()->fields([
            Text::make('Session Name')
                ->name('name')
                ->alternativeName('session-name')
                ->placeholder('E.g. Lunch break')
                ->rules(['required', 'max:255']),
            TextArea::make('Session Description')
                ->name('description')
                ->alternativeName('session-description')
                ->placeholder('Description of session')
                ->rules(['nullable', 'max:255']),
            TimeInput::make('Start time')
                ->name('starting_at')
                ->alternativeName('session-start-time')
                ->rules(['required', 'before:ending_at', new NoOverlap($pathway)]),
            TimeInput::make('End time')
                ->name('ending_at')
                ->alternativeName('session-end-time')
                ->rules(['required', 'after:starting_at', new NoOverlap($pathway)]),
            Text::make('Add a location')
                ->name('location')
                ->alternativeName('session-location')
                ->placeholder('E.g Canteen')
                ->rules(['required', 'max:255']),
        ]),
    ];
};

Form::make('session.create')
    ->addSaveHandler(new CreateModel)
    ->addSaveHandler(new AssociateToPathway)
    ->addFields($fields);

Form::make('session.update')
    ->addSaveHandler(new UpdateModel)
    ->addFields($fields);
