<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Component\Scope;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Enums\InertiaMethod;

Form::make('venue.create')
    ->addSaveHandler(new CreateModel)
    ->model(new Venue)
    ->addFields(function () {
        return [
            Section::make('Key Details')->fields([
                Text::make('Name')->rules(['required']),
                Text::make('Url')
                    ->rules(['required'])
                    ->placeholder('http://google.com/'),
            ]),
        ];
    })
    ->addActions(function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.venue.index'),
            Button::make('Add Venue')
                ->method(InertiaMethod::POST())
                ->route('admin.venue.store'),
        ];
    });

Form::make('venue.edit')
    ->addSaveHandler(new UpdateModel)
    ->addFields(function (Venue $venue) {
        return [
            Section::make('Key Details')->fields([
                Text::make('Name')->rules(['required']),
                Text::make('Url')
                    ->rules(['required'])
                    ->placeholder(config('app.url')),
            ]),
        ];
    })
    ->addActions(function (Venue $venue) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.venue.index'),
            Button::make('Update Venue')
                ->method(InertiaMethod::POST())
                ->route('admin.venue.update', ['venue' => $venue]),
        ];
    });

Form::make('venue.show')
    ->addActions(function (Venue $venue) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.venue.index'),
            Button::make('Edit Venue')
                ->method(InertiaMethod::VISIT())
                ->route('admin.venue.edit', ['venue' => $venue]),
        ];
    });


Form::make('venue.edit')
    ->addFields(function () {
        return [
            Section::make('Key Details')->fields([
                Text::make('Name')->rules(['required']),
                Text::make('Url')
                    ->rules(['required'])
                    ->placeholder('http://google.com/'),
            ]),
        ];
    });

Form::make('venue.show')
    ->addFields(function () {
        return [
            Section::make('Key Details')->fields([
                Display::make('Name'),
                Display::make('Url'),
            ]),

            Section::make('Address')->fields([
                Display::make('Name')->scopeTo('address'),
                Display::make('First Line')->name('line_1')->scopeTo('address'),
                Display::make('Second Line')->name('line_2')->scopeTo('address'),
                Display::make('Third Line')->name('line_3')->scopeTo('address'),
                Display::make('City')->scopeTo('address'),
                Display::make('County')->scopeTo('address'),
                Display::make('Country')->scopeTo('address'),
                Display::make('Postcode')->scopeTo('address'),
            ]),
        ];
    });
