<?php

namespace EventPortal\Domain\Agenda\Actions;

use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use Illuminate\Support\Arr;
use Illuminate\Support\Carbon;

class CreateDefaultAgenda
{
    /**
     * @param string|array $dates
     */
    public function execute(Event $event, $dates): void
    {
        foreach (Arr::wrap($dates) as $date) {
            $this->createAgenda($event, $date);
        }
    }

    private function createAgenda(Event $event, string $date): void
    {
        $date = Carbon::createFromFormat('Y-m-d', $date);

        $agenda = Agenda::createForEvent($event, $date);

        $pathway = Pathway::createForAgenda(
            $agenda,
            'Default Pathway',
            'This is the default pathway.'
        );

        Form::make('session.create')
            ->model(new Session)
            ->context($pathway)
            ->save([
                'name' => 'Example Session',
                'description' => 'Example session description',
                'location' => 'Reception',
                'starting_at' => $date->setTime(9, 0),
                'ending_at' => $date->clone()->setTime(10, 0),
            ]);
    }
}
