<?php

namespace EventPortal\Domain\Team\Models;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Concerns\HasTable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\MorphToMany;
use Illuminate\Support\Str;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class Team extends Model implements AuditableInterface
{
    use HasTable, Auditable;

    public const KEY = 'team';

    /** @var array<string> */
    protected $fillable = [
        'name',
        'slug',
        'description',
    ];

    public function admins(): MorphToMany
    {
        return $this->morphedByMany(Admin::class, 'teamable')->withTimestamps();
    }

    public function events(): MorphToMany
    {
        return $this->morphedByMany(Event::class, 'teamable')->withTimestamps();
    }

    public static function asOptions(): array
    {
        return Team::all()
            ->map(function (Team $team) {
                return Option::make($team->name)->value($team->id);
            })
            ->toArray();
    }

    protected static function booted(): void
    {
        static::creating(static function (Team $team): void {
            /**
             * If no slug is set, create one from the name. (I'm guessing this
             * will be replaced at some point with a sluggable package)
             */
            $team->slug = $team->slug ?? Str::slug($team->name);
        });
    }
}
