<?php

namespace EventPortal\Domain\Venue\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Domain\Address\Models\Address;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\MorphOne;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class Venue extends Model implements AuditableInterface
{
    use HasTable,
        AddToFillable,
        AddToCasts,
        Auditable;

    public const KEY = 'venue';

    /** @var array<string> */
    protected $fillable = [
        'name',
        'url',
    ];

    /** @var array<string> */
    protected $with = [
        'address',
    ];

    public function events(): HasMany
    {
        return $this->hasMany(Event::class);
    }

    public function address(): MorphOne
    {
        return $this->morphOne(Address::class, 'addressable');
    }
}
