<?php

namespace EventPortal\Http\Controllers\Admin\EventDelegate;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Domain\Util\Render;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Database\Query\JoinClause;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Inertia\Response;

class EventDelegateController extends Controller
{
    public function index(Event $event): Response
    {
        $query = Delegate::query()
            ->join('delegate_event', function (JoinClause $query) {
                return $query->on('delegates.id', '=', 'delegate_event.delegate_id');
            })
            ->where('delegate_event.event_id', '=', $event->id);

        $table = Table::make('event-delegate.index')
            ->context($event)
            ->query($query)
            ->request(request())
            ->get();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('Delegates')
            ->get();

        return Render::component('EventDelegate/Index')
            ->key('event.delegate.index')
            ->withTable($table)
            ->withBreadcrumbs($breadcrumbs)
            ->attributes(['event' => $event])
            ->get();
    }

    public function store(Request $request, Event $event): RedirectResponse
    {
        Form::make('delegate.create')
            ->model(new Delegate)
            ->context($event)
            ->validate($request->all())
            ->save($request->all());

        return redirect()->route('admin.event.delegate.create', $event);
    }

    public function show(Event $event, Delegate $delegate): Response
    {
        $eventDelegate = EventDelegate::forEventAndDelegate($event, $delegate)->first();

        $delegateData = Form::make('event-delegate.show')
            ->model($delegate)
            ->context($event, $eventDelegate)
            ->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('View Delegate')
            ->get();

        return Render::component('EventDelegate/Show')
            ->key('event.delegate.show')
            ->withForms([
                'delegateData' => $delegateData,
                'registrationData' => $delegateData,
            ])
            ->withBreadcrumbs($breadcrumbs)
            ->withTitle($delegate->name)
            ->get();
    }
}
