<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Enums\InertiaMethod;

Table::make('venue.index')
    ->joinRelation('address')
    ->addAvailableColumns(function () {
        return [
            Text::make('Venue name')->name('name'),
            Text::make('Venue URL')->name('url'),
            Text::make('Line 1')->scopeTo('address'),
            Text::make('Line 2')->scopeTo('address'),
            Text::make('Line 3')->scopeTo('address'),
            Text::make('City')->scopeTo('address'),
            Text::make('County')->scopeTo('address'),
            Text::make('Country')->scopeTo('address'),
            Text::make('Postcode')->scopeTo('address'),
        ];
    })
    ->addDefaultColumns(function () {
        return [
            Text::make('Venue name')->name('name'),
            Text::make('Venue URL')->name('url'),
            Text::make('Postcode')->scopeTo('address'),
        ];
    })
    ->addRowAction(function (Venue $venue) {
        return ButtonDropdown::make('Manage venue')
            ->actions([
                Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.venue.show', [
                        'venue' => $venue->id,
                    ]),
                Button::make('Edit')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.venue.edit', [
                        'venue' => $venue->id,
                    ]),
            ]);
    });
