<?php

namespace EventPortal\Tests\Feature\Admin\Venue;

use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Arr;
use Spatie\Snapshots\MatchesSnapshots;

class VenueRouteTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions, MatchesSnapshots;
    /** @test */
    public function can_get_index_route()
    {
        $venue = factory(Venue::class)
            ->state('has-address')
            ->create(['name' => 'Test Venue', 'url' => 'http://example.com']);

        $this->assertMatchesJsonSnapshot($this->actingAsSuperAdmin()
            ->get(route('admin.venue.index'))
            ->props());
    }

    /** @test */
    public function can_view_venue()
    {
        $this->withoutExceptionHandling();
        $venue = factory(Venue::class)
            ->state('has-address')
            ->create(['name' => 'Test Venue', 'url' => 'http://example.com']);

        $venuePayload = $this->actingAsSuperAdmin()
            ->get(route('admin.venue.show', $venue))
            ->assertOk()
            ->props();

        $content = $venuePayload['data']['content'][0]['children'];

        $this->assertMatchesJsonSnapshot($venuePayload);

        $this->assertContains('Test Venue', $content[0]);
        $this->assertContains('http://example.com', $content[1]);
    }
}
