<?php

namespace EventPortal\Tests\Feature\Admin\Venue;

use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class VenueStoreTest extends TestCase
{
    use DatabaseMigrations, SeedRolesAndPermissions;

    /** @test */
    public function a_venue_can_be_created(): void
    {
        $this->withoutExceptionHandling();

        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.venue.store'), [
                'name' => 'A Venue',
                'url' => 'http://thicc.so',
            ])
            ->assertOk();

        $this->assertDatabaseHas('venues', [
            'name' => 'A Venue',
            'url' => 'http://thicc.so',
        ]);
    }

    /** @test **/
    public function the_venue_name_is_required(): void
    {

        $this
            ->actingAsSuperAdmin()
            ->post(route('admin.venue.store'), [
                'name' => null,
                'url' => 'http://url.com',
            ])
            ->assertSessionHasErrors([
                'name',
            ]);

        $this->assertDatabaseMissing('venues', [
            'url' => 'http://url.com',
        ]);
    }

    /** @test **/
    // public function the_slug_can_be_generated_automatically()
    // {
    //     $user = factory(User::class)->create();

    //     $this
    //         ->actingAs($user)
    //         ->followingRedirects()
    //         ->post(route('admin.team.store'), [
    //             'name' => 'New Team',
    //             'slug' => null,
    //         ])
    //         ->assertOk();

    //     $this->assertDatabaseHas('teams', [
    //         'name' => 'New Team',
    //         'slug' => 'new-team'
    //     ]);
    // }
}
