<?php

namespace EventPortal\Tests\Feature\Admin\Venue;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use EventPortal\Domain\Venue\Models\Venue;
use Illuminate\Foundation\Testing\RefreshDatabase;

class VenueUpdateTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions;

    /** @test */
    public function a_venue_can_be_updated()
    {
        $venue = factory(Venue::class)->create([
            'name' => 'Original Name',
            'url' => 'http://original.example.com',
        ]);

        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.venue.update', $venue), [
                'name' => 'New Name',
                'url' => 'http://new.example.com',
                ])
            ->assertOk();

        $this->assertDatabaseHas('venues', [
            'name' => 'New Name',
            'url' => 'http://new.example.com',
            ]);
    }

    /** @test **/
    public function the_venue_name_is_required()
    {
        $venue = factory(Venue::class)->create([
            'name' => 'Original Name',
        ]);

        $this
            ->actingAsSuperAdmin()
            ->post(route('admin.venue.update', $venue), [
                'name' => null,
            ])
            ->assertSessionHasErrors([
                'name',
            ]);

        $this->assertDatabaseHas('venues', [
            'name' => 'Original Name',
        ]);
    }
}
