<?php

namespace EventPortal\Tests\Unit\Venue;

use EventPortal\Domain\Address\Models\Address;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Venue\Actions\DisassociateFromEvent;
use EventPortal\Domain\Venue\Actions\AssociateToEvent;
use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class VenueTest extends TestCase
{
    use RefreshDatabase;

    /** @test */
    public function can_get_address_from_venue()
    {
        $venue = factory(Venue::class)->create(['name' => 'Test Venue']);
        $address = factory(Address::class)->make();

        $venue->address()->save($address);

        $this->assertSameModel($address, $venue->address);
    }

    /** @test */
    public function can_assign_to_event()
    {
        $venue = factory(Venue::class)->state('has-address')->create();
        $event = factory(Event::class)->create();

        $this->assertEmpty($venue->events);
        $this->assertNull($event->venue);

        $this->associate()->execute($event, $venue);

        $this->assertSameModel($venue, $event->venue);
    }

    /** @test */
    public function can_remove_from_event()
    {
        $venue = factory(Venue::class)->state('has-address')->create();
        $event = factory(Event::class)->create(['venue_id' => $venue->id]);
        
        $this->assertNotEmpty($venue->events);
        $this->assertSameModel($venue, $event->venue);
        
        $this->disassociate()->execute($event, $venue);
        
        $this->assertNull($event->venue);
    }

    public function associate(): AssociateToEvent
    {
        return app(AssociateToEvent::class);
    }

    public function disassociate(): DisassociateFromEvent
    {
        return app(DisassociateFromEvent::class);
    }
}
